@@ -20,8 +20,8 @@ Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-02111-1307  USA
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301  USA
 
 */
 
@@ -2240,7 +2240,7 @@ lt_dlopen (filename)
 	else if (strncmp (line, STR_LIBDIR, sizeof (STR_LIBDIR) - 1) == 0)
 	  {
 	    error = trim (&libdir, &line[sizeof(STR_LIBDIR) - 1]);
-#ifdef _WIN32
+#if defined(_WIN32) && !defined(__CYGWIN__)
 	    win32_mapDir(&libdir);
 #endif
 	  }
